@@ -1,4 +1,4 @@
-
+from typing import Optional
 from opentelemetry import trace
 from opentelemetry.sdk.trace import TracerProvider
 from opentelemetry.sdk.trace.export import (
@@ -32,6 +32,9 @@ from langtrace_python_sdk.instrumentation.openai.instrumentation import (
 from langtrace_python_sdk.instrumentation.pinecone.instrumentation import (
     PineconeInstrumentation,
 )
+from langtrace_python_sdk.instrumentation.cohere.instrumentation import (
+    CohereInstrumentation,
+)
 
 
 def init(
@@ -40,12 +43,12 @@ def init(
     write_to_langtrace_cloud: bool = True,
     debug_log_to_console: bool = False,
     custom_remote_exporter=None,
+    api_host: Optional[str] = None,
 ):
-
     provider = TracerProvider()
 
     remote_write_exporter = (
-        LangTraceExporter(api_key, write_to_langtrace_cloud)
+        LangTraceExporter(api_key, write_to_langtrace_cloud, api_host=api_host)
         if custom_remote_exporter is None
         else custom_remote_exporter
     )
@@ -77,6 +80,7 @@ def init(
     langchain_core_instrumentation = LangchainCoreInstrumentation()
     langchain_community_instrumentation = LangchainCommunityInstrumentation()
     anthropic_instrumentation = AnthropicInstrumentation()
+    cohere_instrumentation = CohereInstrumentation()
 
     # Call the instrument method with some arguments
     openai_instrumentation.instrument()
@@ -87,3 +91,4 @@ def init(
     langchain_core_instrumentation.instrument()
     langchain_community_instrumentation.instrument()
     anthropic_instrumentation.instrument()
+    cohere_instrumentation.instrument()
